@@ -37,6 +37,7 @@ cli_util.rename_command(aiservicelanguage_cli, aiservicelanguage_cli.batch_detec
 cli_util.rename_command(aiservicelanguage_cli, aiservicelanguage_cli.batch_detect_language_sentiments_group, aiservicelanguage_cli.batch_detect_language_sentiments, "batch-detect-sentiments")
 cli_util.rename_command(aiservicelanguage_cli, aiservicelanguage_cli.batch_detect_language_text_classification_group, aiservicelanguage_cli.batch_detect_language_text_classification, "batch-detect-text-classification")
 cli_util.rename_command(aiservicelanguage_cli, aiservicelanguage_cli.batch_detect_language_pii_entities_group, aiservicelanguage_cli.batch_detect_language_pii_entities, "batch-detect-pii-entities")
+cli_util.rename_command(aiservicelanguage_cli, aiservicelanguage_cli.batch_detect_health_entity_details_group, aiservicelanguage_cli.batch_detect_health_entity, "batch-detect-health-entities")
 
 # Single Documents APIs
 cli_util.rename_command(aiservicelanguage_cli, aiservicelanguage_cli.detect_dominant_language_group, aiservicelanguage_cli.detect_dominant_language, "detect-language")
@@ -55,6 +56,7 @@ aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.batch_det
 aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.batch_detect_language_sentiments_group.name)
 aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.batch_detect_language_text_classification_group.name)
 aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.batch_detect_language_pii_entities_group.name)
+aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.batch_detect_health_entity_details_group.name)
 
 # Single Documents APIs
 aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.detect_dominant_language_group.name)
@@ -71,6 +73,7 @@ language_group.add_command(aiservicelanguage_cli.batch_detect_language_key_phras
 language_group.add_command(aiservicelanguage_cli.batch_detect_language_sentiments)
 language_group.add_command(aiservicelanguage_cli.batch_detect_language_text_classification)
 language_group.add_command(aiservicelanguage_cli.batch_detect_language_pii_entities)
+language_group.add_command(aiservicelanguage_cli.batch_detect_health_entity)
 
 # Single Documents APIs
 aiservicelanguage_cli.ai_root_group.add_command(language_group)
@@ -93,7 +96,6 @@ aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_mode
 aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_named_entity_recognition_model_details.name)
 aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_language_detection_model_details.name)
 aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_sentiment_analysis_model_details.name)
-aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_phi_model_details.name)
 aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_text_classification_model_details.name)
 aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_summarization.name)
 aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pre_trained_pii_model_details.name)
@@ -129,3 +131,17 @@ language_group.add_command(aiservicelanguage_cli.model_type_info_group)
 # Add work-request error and logs messages to work-request group
 aiservicelanguage_cli.work_request_group.add_command(aiservicelanguage_cli.work_request_error_group)
 aiservicelanguage_cli.work_request_group.add_command(aiservicelanguage_cli.work_request_log_group)
+
+
+# Remove polymorphic job group commands
+aiservicelanguage_cli.job_group.commands.pop(aiservicelanguage_cli.create_job_object_storage_file_name_location.name)
+aiservicelanguage_cli.job_group.commands.pop(aiservicelanguage_cli.create_job_object_storage_prefix_location.name)
+
+# Remove job group from root
+aiservicelanguage_cli.ai_root_group.commands.pop(aiservicelanguage_cli.job_group.name)
+
+# Add Job group to language group
+language_group.add_command(aiservicelanguage_cli.job_group)
+
+# Remove polymorphic model group command
+aiservicelanguage_cli.model_group.commands.pop(aiservicelanguage_cli.create_model_pii_model_details.name)
