@@ -206,6 +206,7 @@ dbmanagement_cli.managed_database_group.add_command(dbmanagement_cli.get_user)
 
 # Move commands under 'oci database-management db-management' -> 'oci database-management'
 database_management_service_cli.database_management_service_group.commands.pop(dbmanagement_cli.db_management_root_group.name)
+database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.named_credential_group)
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.cluster_cache_metric_group)
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.work_request_log_entry_group)
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.managed_database_group_group)
@@ -235,6 +236,8 @@ database_management_service_cli.database_management_service_group.add_command(db
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.external_cluster_group)
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.external_db_system_group)
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.external_db_node_group)
+database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.peer_database_metrics_group)
+database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.dataguard_performance_metrics_group)
 
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.external_exadata_infrastructure_group)
 database_management_service_cli.database_management_service_group.add_command(dbmanagement_cli.external_exadata_storage_connector_group)
